[java-idp-integration-tests] branch master updated: INFRA-150 - Replace '\' with '/' when setting idp.home.

Tom Zeller tzeller at dragonacea.biz
Mon Jan 18 15:54:10 EST 2016


This is an automated email from the git hooks/post-receive script.

tzeller pushed a commit to branch master
in repository java-idp-integration-tests.

The following commit(s) were added to refs/heads/master by this push:
       new  f4efdcf   INFRA-150 - Replace '\' with '/' when setting idp.home.
f4efdcf is described below

commit f4efdcf785acae012de780d248a5fe1c4485ce2b
Author: Tom Zeller <tzeller at dragonacea.biz>
AuthorDate: Mon Jan 18 14:55:46 2016 -0600

    INFRA-150 - Replace '\' with '/' when setting idp.home.
    
    Otherwise, Spring Web Flow will not compute the proper flow IDs on
    Windows.
---
 src/test/java/net/shibboleth/idp/test/BaseIntegrationTest.java | 4 ++--
 1 file changed, 2 insertions(+), 2 deletions(-)

diff --git a/src/test/java/net/shibboleth/idp/test/BaseIntegrationTest.java b/src/test/java/net/shibboleth/idp/test/BaseIntegrationTest.java
index fa4276d..307d610 100644
--- a/src/test/java/net/shibboleth/idp/test/BaseIntegrationTest.java
+++ b/src/test/java/net/shibboleth/idp/test/BaseIntegrationTest.java
@@ -369,8 +369,8 @@ public abstract class BaseIntegrationTest
         FileSystemUtils.copyRecursively(sourceDir, destinationDir);
         Assert.assertTrue(destinationDir.exists(), "Path to idp.home not found");
 
-        // Set idp.home system property
-        System.setProperty("idp.home", pathToIdPHome.toAbsolutePath().toString());
+        // Set idp.home system property, replace '\' with '/' for Windows
+        System.setProperty("idp.home", pathToIdPHome.toAbsolutePath().toString().replace('\\', '/'));
 
         // Path to embedded/jetty.base
         final Path pathToEmbeddedJettyBase = pathToIdPHome.resolve(Paths.get("embedded", "jetty-base"));

-- 
To stop receiving notification emails like this one, please contact
the administrator of this repository.


More information about the commits mailing list